@@ -308,6 +308,9 @@ class VirtualService(BaseKempObject):
         if hasattr(self, "persist") and self.persist is None:
             self.persisttimeout = None
 
+        if self.subvs_entries:
+            self.enhancedhealthchecks = None
+
         if not update:
             if self._is_sub_vs:
                 # Hell, thy name be subvs
@@ -330,7 +333,7 @@ class VirtualService(BaseKempObject):
                 response = self._get("/showvs", newly_created_vs_params)
             else:
                 response = self._get("/addvs", self.to_api_dict())
-        else:
+        else:  # Update
             if self._is_sub_vs:
                 # Update the underlying "Rs" part of the subvs as well
                 self._get("/modrs", self._subvs_to_dict())
